
******************
Command-line tools
******************

Overview
========

.. autosummary::

    shelephant.cli.shelephant_dump
    shelephant.cli.shelephant_checksum
    shelephant.cli.shelephant_cp
    shelephant.cli.shelephant_mv
    shelephant.cli.shelephant_rm
    shelephant.cli.shelephant_hostinfo
    shelephant.cli.shelephant_get
    shelephant.cli.shelephant_send
    shelephant.cli.shelephant_merge
    shelephant.cli.shelephant_parse
    shelephant.cli.shelephant_extract

List files
==========

shelephant_dump
---------------

.. automodule:: shelephant.cli.shelephant_dump

shelephant_checksum
-------------------

.. automodule:: shelephant.cli.shelephant_checksum

Basic copying
=============

shelephant_cp
-------------

.. automodule:: shelephant.cli.shelephant_cp

shelephant_mv
-------------

.. automodule:: shelephant.cli.shelephant_mv

shelephant_rm
-------------

.. automodule:: shelephant.cli.shelephant_rm

Copying over SSH
================

shelephant_hostinfo
-------------------

.. automodule:: shelephant.cli.shelephant_hostinfo

shelephant_get
--------------

.. automodule:: shelephant.cli.shelephant_get

shelephant_send
---------------

.. automodule:: shelephant.cli.shelephant_send

Synchronisation information
===========================

shelephant_diff
---------------

.. argparse::
    :module: helephant
    :func: _shelephant_diff_parser
    :prog: shelephant_diff

Modifying YAML-file
===================

shelephant_merge
----------------

.. automodule:: shelephant.cli.shelephant_merge

shelephant_parse
----------------

.. automodule:: shelephant.cli.shelephant_parse

shelephant_extract
------------------

.. automodule:: shelephant.cli.shelephant_extract
